[svn:parrot] r38400 - in branches/pmc_pct: compilers/pmc/src config/gen/makefiles

bacek at svn.parrot.org bacek at svn.parrot.org
Wed Apr 29 10:42:32 UTC 2009


Author: bacek
Date: Wed Apr 29 10:42:31 2009
New Revision: 38400
URL: https://trac.parrot.org/parrot/changeset/38400

Log:
Rename PMC::Compiler to PMC::Emitter

Added:
   branches/pmc_pct/compilers/pmc/src/emitter.pm
      - copied, changed from r38399, branches/pmc_pct/compilers/pmc/src/compiler.pm
Deleted:
   branches/pmc_pct/compilers/pmc/src/compiler.pm
Modified:
   branches/pmc_pct/config/gen/makefiles/pmc.in

Deleted: branches/pmc_pct/compilers/pmc/src/compiler.pm
==============================================================================
--- branches/pmc_pct/compilers/pmc/src/compiler.pm	Wed Apr 29 10:42:31 2009	(r38399)
+++ /dev/null	00:00:00 1970	(deleted)
@@ -1,64 +0,0 @@
-# Copyright (C) 2009, Parrot Foundation.
-# $Id$
-
-# Main PMC compiler.
-
-class PMC::Compiler;
-
-
-# Generate .h file for pmc.
-method generate_h_file() {
-    my $res;
-
-    #my $self; PIR q< store_lex "$self", self >;
-    my $filename := self.filename();
-    $res := dont_edit($filename);
-
-    $res := $res ~ c_code_coda();
-
-    $res;
-}
-
-method filename() {
-    our $?filename;
-    $?filename;
-}
-
-method set_filename($name) {
-    our $?filename := $name;
-}
-
-# Generate don't edit warning
-sub dont_edit($filename) {
-     "/* ex: set ro ft=c:\n"
-    ~" * !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!\n"
-    ~" *\n"
-    ~" * This file is generated automatically from '" ~$filename ~"'\n"
-    ~" * by Divine Intervention.\n"
-    ~" *\n"
-    ~" * Any changes made here will be lost!\n"
-    ~" *\n"
-    ~" */\n";
-}
-
-#=item C<c_code_coda()>
-#
-#Returns the Parrot C code coda
-#
-#=back
-#
-#=cut
-sub c_code_coda() {
-     "/*\n"
-    ~" * Local variables:\n"
-    ~" *   c-file-style: parrot\n"
-    ~" * End:\n"
-    ~" * vim: expandtab shiftwidth=4:\n"
-    ~" */\n"
-}
-
-# Local Variables:
-#   mode: perl6
-#   fill-column: 100
-# End:
-# vim: expandtab shiftwidth=4:

Copied and modified: branches/pmc_pct/compilers/pmc/src/emitter.pm (from r38399, branches/pmc_pct/compilers/pmc/src/compiler.pm)
==============================================================================
--- branches/pmc_pct/config/gen/makefiles/pmc.in	Wed Apr 29 09:45:41 2009	(r38399)
+++ branches/pmc_pct/config/gen/makefiles/pmc.in	Wed Apr 29 10:42:31 2009	(r38400)
@@ -20,7 +20,7 @@
   src/vtable_info.pir \
   src/parser/gen_grammar.pir \
   src/parser/gen_actions.pir \
-  src/gen_compiler.pir \
+  src/gen_emitter.pir \
   src/gen_vtable_info.pir \
   src/builtins.pir
 
@@ -39,9 +39,9 @@
 	$(PARROT) $(PARROT_ARGS) $(NQP) --output=src/parser/gen_actions.pir \
 	    --target=pir src/parser/actions.pm
 
-src/gen_compiler.pir: $(NQP) $(PCT) src/compiler.pm
-	$(PARROT) $(PARROT_ARGS) $(NQP) --output=src/gen_compiler.pir \
-	    --target=pir src/compiler.pm
+src/gen_emitter.pir: $(NQP) $(PCT) src/emitter.pm
+	$(PARROT) $(PARROT_ARGS) $(NQP) --output=src/gen_emitter.pir \
+	    --target=pir src/emitter.pm
 
 src/gen_vtable_info.pir: $(NQP) $(PCT) src/vtable_info.pm
 	$(PARROT) $(PARROT_ARGS) $(NQP) --output=src/gen_vtable_info.pir \
@@ -78,7 +78,7 @@
   pmc.pbc \
   src/parser/gen_grammar.pir \
   src/parser/gen_actions.pir \
-  src/gen_compiler.pir \
+  src/gen_emitter.pir \
   src/gen_vtable_info.pir
 
 


More information about the parrot-commits mailing list
--- branches/pmc_pct/compilers/pmc/src/compiler.pm	Wed Apr 29 09:45:41 2009	(r38399, copy source)
+++ branches/pmc_pct/compilers/pmc/src/emitter.pm	Wed Apr 29 10:42:31 2009	(r38400)
@@ -1,9 +1,9 @@
 # Copyright (C) 2009, Parrot Foundation.
 # $Id$
 
 # Main PMC compiler.
 
-class PMC::Compiler;
+class PMC::Emitter;
 
 
 # Generate .h file for pmc.
@@ -1,9 +1,9 @@
 # $Id$
 
-# Main PMC compiler.
+# Main PMC Emitter.
 

Modified: branches/pmc_pct/config/gen/makefiles/pmc.in
==============================================================================